==> jc-1.4.0.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry.h <==
// public final class org.w3c.dom.bootstrap.DOMImplementationRegistry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4515c381e7cb98e9 org_w3c_dom_bootstrap_DOMImplementationRegistry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_DOMImplementationList$object;
struct _jc_org_w3c_dom_DOMImplementationSource$object;
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype;

// Class fields structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct {
	struct _jc_java_lang_String$object	*PROPERTY;
	struct _jc_java_lang_Class$object	*class__24org__24w3c__24dom__24bootstrap__24DOMImplementationRegistry;
	jint	DEFAULT__5fLINE__5fLENGTH;
};
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$class_fields;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$_init$7daa05b6e050118a(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$addSource$890bddf585dbc993(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_object *);
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getDOMImplementation$d6af02b546b219ba(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getDOMImplementationList$53d8a0e2cc1a5bf2(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$addSource$890bddf585dbc993;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$getDOMImplementation$d6af02b546b219ba;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$getDOMImplementationList$53d8a0e2cc1a5bf2;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_ClassLoader$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getClassLoader$2078dc747ca30d6e(_jc_env *);
extern struct _jc_java_lang_ClassLoader$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getContextClassLoader$8df97c408c9fbc5d(_jc_env *);
extern struct _jc_java_io_InputStream$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getResourceAsStream$425e0c8c289feb9d(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getServiceValue$04253867a58d94a0(_jc_env *, struct _jc_java_lang_ClassLoader$object *);
extern struct _jc_java_lang_String$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getSystemProperty$3d46824f16217d5d(_jc_env *, struct _jc_java_lang_String$object *);
extern jboolean _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$isJRE11$a4a9fa451285a3d3(_jc_env *);
extern struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$newInstance$98990963bbf7831a(_jc_env *);

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods {
	void	(*addSource$890bddf585dbc993)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_object *);
	struct _jc_object	*(*getDOMImplementation$d6af02b546b219ba)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getDOMImplementationList$53d8a0e2cc1a5bf2)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs {
	struct _jc_java_util_Vector$object	*sources;
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry.h <==
// public final class org.w3c.dom.bootstrap.DOMImplementationRegistry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4515c381e7cb98e9 org_w3c_dom_bootstrap_DOMImplementationRegistry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_DOMImplementationList$object;
struct _jc_org_w3c_dom_DOMImplementationSource$object;
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype;

// Class fields structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct {
	struct _jc_java_lang_String$object	*PROPERTY;
	struct _jc_java_lang_Class$object	*class__24org__24w3c__24dom__24bootstrap__24DOMImplementationRegistry;
	jint	DEFAULT__5fLINE__5fLENGTH;
};
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$fields_struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$class_fields;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$_init$7daa05b6e050118a(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$addSource$890bddf585dbc993(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getDOMImplementation$d6af02b546b219ba(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getDOMImplementationList$53d8a0e2cc1a5bf2(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$addSource$890bddf585dbc993;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$getDOMImplementation$d6af02b546b219ba;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method_info$getDOMImplementationList$53d8a0e2cc1a5bf2;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getClassLoader$2078dc747ca30d6e(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getContextClassLoader$8df97c408c9fbc5d(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getResourceAsStream$425e0c8c289feb9d(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getServiceValue$04253867a58d94a0(_jc_env *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$getSystemProperty$3d46824f16217d5d(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$isJRE11$a4a9fa451285a3d3(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$method$newInstance$98990963bbf7831a(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods {
	void	(*addSource$890bddf585dbc993)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDOMImplementation$d6af02b546b219ba)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDOMImplementationList$53d8a0e2cc1a5bf2)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs {
	struct _jc_java_util_Vector$object	*sources;
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry_H_ */
